Learn R Programming

naturaList (version 0.5.2)

abrev.pttn: Internal function of naturaList - Return abbreviation collapsed

Description

Return collapsed abbreviation for a specific line of specialist data frame. It is used as pattern in grep function inside classify_occ

Usage

abrev.pttn(df, line)

Value

a list with two elements in regex format:

[[1]]

the abbreviation of the first name;

[[2]]

regex pattern with all names and abbreviations.

Arguments

df

spec data frame provided in classify_occ

line

specifies the line of the data frame to be collapsed

See Also

classify_occ