Learn R Programming

naturaList (version 0.5.2)

check.spec: Internal function of naturaList - Manual check of ambiguity in specialist's name

Description

Creates interaction with user in which the user check if a string with the identifier of a specimen has a specialist name. It solves ambiguity in classify an occurrence as identified by a specialist. It is used inside classify_occ

Usage

check.spec(class.occ, crit.levels, identified.by)

Value

a character vector with 'naturaList_levels" ID.

Arguments

class.occ

internal data frame with observation classified according classify_occ criteria

crit.levels

crit.levels choose by user in classify_occ

identified.by

same as identified.by argument in classify_occ