Learn R Programming

naturaList (version 0.5.2)

cyathea.br: Occurrence records of Cyathea species in Brazil downloaded from Global Biodiversity Information Facility (GBIF).

Description

A filtered GBIF dataset containing 3851 occurrence records for the fern species from the genus Cyathea in Brazil. We filtered the data after download from GBIF to ensure all occurrences records are from Brazil.

Usage

cyathea.br

Arguments

Format

A data frame with 3851 rows and 50 variables