Learn R Programming

naturaList (version 0.5.2)

func.det.by.esp: Internal function of naturaList - Detect if a string has a specialist name

Description

Detect if a string with identifiers name has a specialist name. It is used inside classify_occ

Usage

func.det.by.esp(sp.df, i, specialist)

Value

integer with the row numbers of the sp.df data frame which was identified by the specialist name in row i.

Arguments

sp.df

reduced version of occurrence data frame provided in classify_occ

i

row number of specialist data frame

specialist

specialist data