Learn R Programming

naturaList (version 0.5.2)

has.det.ID: Internal function of naturaList - Identifies if a occurrence has a name for the identifier of the specimen

Description

Identifies if a occurrence has a name for the identifier of the specimen. It is used inside classify_occ

Usage

has.det.ID(sp.df, ignore.det.names = NULL)

Arguments

sp.df

reduced version of occurrence data frame provided in classify_occ

ignore.det.names

ignore.det.names character vector indicating strings in the identified.by column that should be ignored as a taxonomist. See classify_occ.

@return an integer vector indicating the rows which have 'identified by' ID