Learn R Programming

naturaList (version 0.5.2)

specialist.conference: Internal function of naturaList - Confirm if an occurrence record was identified by a specialist without ambiguity

Description

Confirm if an occurrence record was identified by a specialist without ambiguity. It is used inside classify_occ

Usage

specialist.conference(pt.df, specialist)

Value

character with naturaList level code "1_det_by_spec" or

"1_det_by_spec_verify"

Arguments

pt.df

a line of the reduced version of the occurrence data frame

specialist

specialist data frame