Learn R Programming

naturaList (version 0.5.2)

verify.specialist: Internal function of naturaList - Verify if a string has unambiguous specialist name

Description

Based on pattern generated by pttn.all.specialist it verifies if a string has unambiguous specialist name. It is used in internal function specialist.conference

Usage

verify.specialist(pattern, string)

Value

character. "" or "_verify".

Arguments

pattern

a pattern from pttn.all.specialist function

string

string with the name of who identified the specimen