powered by
Return collapsed abbreviation for a specific line of specialist data frame. It is used as pattern in grep function inside classify_occ
abrev.pttn(df, line)
a list with two elements in regex format:
the abbreviation of the first name;
regex pattern with all names and abbreviations.
spec data frame provided in classify_occ
specifies the line of the data frame to be collapsed
classify_occ