Creates interaction with user in which the user check if a string with the identifier of a specimen has a specialist name. It solves ambiguity in classify an occurrence as identified by a specialist. It is used inside classify_occ
check.spec(class.occ, crit.levels, identified.by)a character vector with 'naturaList_levels" ID.
internal data frame with observation classified according classify_occ criteria
crit.levels choose by user in classify_occ
same as identified.by argument in classify_occ