Detect if a string with identifiers name has a specialist name. It is used inside classify_occ
func.det.by.esp(sp.df, i, specialist)integer with the row numbers of the sp.df data frame which was
identified by the specialist name in row i.
reduced version of occurrence data frame provided in classify_occ
row number of specialist data frame
specialist data