powered by
This function facilitates the search for non-taxonomist strings in the 'identified.by' column of occurrence records data set
get_det_names( occ, identified.by = "identifiedBy", freq = FALSE, decreasing = TRUE, determined.by )
character vector containing the strings in identified.by
identified.by
column of occ. If freq = TRUE it return a data frame with two columns: 'strings' and 'frequency'.
occ
freq = TRUE
data frame with occurrence records information.
column name of occ with the name of who determined the species.
logical. If TRUE output contain the number of times each string is repeated in the identified.by column. Default = FALSE
TRUE
FALSE
logical. sort strings in decreasing order of frequency. Default = TRUE.
deprecated, use identified.by instead.
data("A.setosa") get_det_names(A.setosa, freq = TRUE)
Run the code above in your browser using DataLab