Confirm if an occurrence record was identified by a specialist without ambiguity. It is used inside classify_occ
specialist.conference(pt.df, specialist)character with naturaList level code "1_det_by_spec" or
"1_det_by_spec_verify"
a line of the reduced version of the occurrence data frame
specialist data frame